import React from 'react';
import KnowledgeCard from './KnowledgeCard';

/**
 * 知识库列表组件
 */
const KnowledgeBaseList = ({ knowledgeBases, isSearching, onCardClick, onRequestAccess, onDelete }) => {
    if (!knowledgeBases?.length) {
        return (
            <div className='alert alert-warning'>
                {isSearching ? '没有找到匹配的知识库' : '暂无知识库，请创建新的知识库'}
            </div>
        );
    }

    return (
        <div className='row gap-3 m-0'>
            {knowledgeBases.map((item) => (
                <React.Fragment key={item.id}>
                    <KnowledgeCard
                        id={item.id}
                        title={item.highlighted_name || item.name}
                        description={item.desc || ''}
                        documents={item.document_count}
                        date={new Date(item.create_time).toLocaleDateString()}
                        permissions={item.permissions}
                        access={item.permissions?.can_edit ? 'full' : item.permissions?.can_read ? 'read' : 'none'}
                        onClick={() => onCardClick(item.id, item.permissions)}
                        onRequestAccess={onRequestAccess}
                        onDelete={(e) => onDelete(e, item.id)}
                        type={item.type}
                        department={item.department}
                        group={item.group}
                    />
                </React.Fragment>
            ))}
        </div>
    );
};

export default KnowledgeBaseList;
